package git

import (
	"buildme/utils"
	"io/ioutil"
	"os"
	"path/filepath"

	"buildme"

	"dev.hexasoftware.com/hxs/prettylog"
	git "gopkg.in/src-d/go-git.v4"
)

var (
	log = prettylog.New("GitFetcher")
)

func init() {
	// Register fetcher
	buildme.RegisterFetcher("git", &Git{})
}

type Git struct {
}

// Fetcher return a project
func (g *Git) Fetch(fpath string) (*buildme.Project, error) {
	log.Println("Building git repo:", fpath)

	projName := filepath.Base(fpath)

	tmpdir, err := ioutil.TempDir("/tmp", "buildme.")
	if err != nil {
		return nil, err
	}

	log.Println("Cloning to:", tmpdir)
	git.PlainClone(tmpdir, false, &git.CloneOptions{
		URL:      fpath,
		Progress: os.Stdout,
	})

	log.Println("Taring content")

	/*tarfile, err := ioutil.TempFile("/tmp", "tarbuildme.")
	reader, err := utils.TarDir(tmpdir, tarfile)*/

	tarReader, err := utils.TempTar(tmpdir, os.TempDir(), "buildme.tar")

	log.Println("Removing dir", tmpdir)
	os.RemoveAll(tmpdir)

	return &buildme.Project{tarReader, projName, "docker/Dockerfile.build"}, nil
}
